@@ -6,7 +6,7 @@ sub _getstash { \%{"$_[0]::"} }
 use strict;
 use warnings;
 
-our $VERSION = '2.000004';
+our $VERSION = '2.000005';
 $VERSION = eval $VERSION;
 
 our %INFO;
@@ -19,6 +19,7 @@ our @ON_ROLE_CREATE;
 
 BEGIN {
   *_WORK_AROUND_BROKEN_MODULE_STATE = "$]" < 5.009 ? sub(){1} : sub(){0};
+  *_MRO_MODULE = "$]" < 5.010 ? sub(){"MRO/Compat.pm"} : sub(){"mro.pm"};
 }
 
 sub croak {
@@ -161,6 +162,8 @@ sub create_class_with_roles {
     croak "${role} is not a Role::Tiny" unless $me->is_role($role);
   }
 
+  require(_MRO_MODULE);
+
   my $composite_info = $me->_composite_info_for(@roles);
   my %conflicts = %{$composite_info->{conflicts}};
   if (keys %conflicts) {
@@ -454,7 +457,8 @@ sub _install_does {
 
 sub does_role {
   my ($proto, $role) = @_;
-  foreach my $class (@{_get_isa(ref($proto)||$proto)}) {
+  require(_MRO_MODULE);
+  foreach my $class (@{mro::get_linear_isa(ref($proto)||$proto)}) {
     return 1 if exists $APPLIED_TO{$class}{$role};
   }
   return 0;
@@ -465,30 +469,6 @@ sub is_role {
   return !!($INFO{$role} && ($INFO{$role}{is_role} || $INFO{$role}{not_methods}));
 }
 
-sub _get_isa ($;$) {
-  no warnings 'redefine';
-  if ("$]" >= 5.010) {
-    require mro;
-    *__get_isa = \&mro::get_linear_isa;
-  }
-  else {
-    *__get_isa = \&__get_linear_isa_dfs;
-  }
-  goto &__get_isa;
-}
-
-sub _get_linear_isa_dfs ($;$) {
-  my @isa = shift;
-  my @lin;
-  my %seen;
-  while (my $class = pop @isa) {
-    push @lin, $class;
-    no strict 'refs';
-    push @isa, grep !$seen{$_}++, reverse @{$class.'::ISA'};
-  }
-  return \@lin;
-}
-
 1;
 __END__
 
